==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/AbstractObjectContext.h <==
// abstract class gnu.java.beans.decoder.AbstractObjectContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractContext

#include "gnu/java/beans/decoder/AbstractContext.h"

#ifndef _JC_gnu_java_beans_decoder_AbstractObjectContext_H_
#define _JC_gnu_java_beans_decoder_AbstractObjectContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	_jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	_jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$refs	_jc_gnu_java_beans_decoder_AbstractObjectContext$refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$nonrefs	_jc_gnu_java_beans_decoder_AbstractObjectContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object	_jc_gnu_java_beans_decoder_AbstractObjectContext$object;

typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$fields_struct	_jc_gnu_java_beans_decoder_AbstractObjectContext$fields_struct;
typedef const struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vtable	_jc_gnu_java_beans_decoder_AbstractObjectContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vtype	_jc_gnu_java_beans_decoder_AbstractObjectContext$vtype;

// Class fields structure
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Object;
};
extern _jc_gnu_java_beans_decoder_AbstractObjectContext$fields_struct _jc_gnu_java_beans_decoder_AbstractObjectContext$class_fields;

// Constructors
extern void _jc_gnu_java_beans_decoder_AbstractObjectContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_AbstractObjectContext$method$get$a706240e1333824b(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, jint);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_AbstractObjectContext$method$getResult$945d2e60d6ab8d5c(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *);
extern void _jc_gnu_java_beans_decoder_AbstractObjectContext$method$set$bdfa7111d1276910(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, jint, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_java_beans_decoder_AbstractObjectContext$method$setObject$c9365b5722a2c4bb(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_AbstractObjectContext$method_info$get$a706240e1333824b;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractObjectContext$method_info$getResult$945d2e60d6ab8d5c;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractObjectContext$method_info$set$bdfa7111d1276910;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractObjectContext$method_info$setObject$c9365b5722a2c4bb;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_beans_decoder_AbstractObjectContext$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, jint);
	struct _jc_java_lang_Object$object	*(*getResult$945d2e60d6ab8d5c)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *);
	void	(*set$bdfa7111d1276910)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, jint, struct _jc_java_lang_Object$object *);
	void	(*setObject$c9365b5722a2c4bb)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs {
	struct _jc_java_lang_Object$object	*object;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$refs {
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object {
	_jc_gnu_java_beans_decoder_AbstractObjectContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_AbstractObjectContext$vtype _jc_gnu_java_beans_decoder_AbstractObjectContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_AbstractObjectContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_AbstractObjectContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_AbstractObjectContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/AbstractObjectContext.h <==
// abstract class gnu.java.beans.decoder.AbstractObjectContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractContext

#include "gnu/java/beans/decoder/AbstractContext.h"

#ifndef _JC_gnu_java_beans_decoder_AbstractObjectContext_H_
#define _JC_gnu_java_beans_decoder_AbstractObjectContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	_jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	_jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$refs	_jc_gnu_java_beans_decoder_AbstractObjectContext$refs;
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$nonrefs	_jc_gnu_java_beans_decoder_AbstractObjectContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object	_jc_gnu_java_beans_decoder_AbstractObjectContext$object;

typedef struct _jc_gnu_java_beans_decoder_AbstractObjectContext$fields_struct	_jc_gnu_java_beans_decoder_AbstractObjectContext$fields_struct;
typedef const struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vtable	_jc_gnu_java_beans_decoder_AbstractObjectContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vtype	_jc_gnu_java_beans_decoder_AbstractObjectContext$vtype;

// Class fields structure
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Object;
};
extern _jc_gnu_java_beans_decoder_AbstractObjectContext$fields_struct _jc_gnu_java_beans_decoder_AbstractObjectContext$class_fields;

// Constructors
extern void _jc_gnu_java_beans_decoder_AbstractObjectContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_AbstractObjectContext$method$get$a706240e1333824b(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_AbstractObjectContext$method$getResult$945d2e60d6ab8d5c(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_AbstractObjectContext$method$set$bdfa7111d1276910(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_AbstractObjectContext$method$setObject$c9365b5722a2c4bb(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_AbstractObjectContext$method_info$get$a706240e1333824b;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractObjectContext$method_info$getResult$945d2e60d6ab8d5c;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractObjectContext$method_info$set$bdfa7111d1276910;
extern _jc_method _jc_gnu_java_beans_decoder_AbstractObjectContext$method_info$setObject$c9365b5722a2c4bb;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_beans_decoder_AbstractObjectContext$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods {
	struct _jc_java_lang_Object$object	*(*get$a706240e1333824b)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getResult$945d2e60d6ab8d5c)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *) _JC_JCNI_ATTR;
	void	(*set$bdfa7111d1276910)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*setObject$c9365b5722a2c4bb)(_jc_env *, struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs {
	struct _jc_java_lang_Object$object	*object;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$refs {
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_AbstractObjectContext$object {
	_jc_gnu_java_beans_decoder_AbstractObjectContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_AbstractObjectContext$vtype _jc_gnu_java_beans_decoder_AbstractObjectContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_AbstractObjectContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_AbstractObjectContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_AbstractObjectContext_H_ */
